@@ -1,5 +1,5 @@
 package Net::Stomp::MooseHelpers::TraceOnly;
-$Net::Stomp::MooseHelpers::TraceOnly::VERSION = '2.8';
+$Net::Stomp::MooseHelpers::TraceOnly::VERSION = '2.9';
 {
   $Net::Stomp::MooseHelpers::TraceOnly::DIST = 'Net-Stomp-MooseHelpers';
 }
@@ -28,7 +28,7 @@ around '_build_connection' => sub {
 };
 
 package Net::Stomp::MooseHelpers::TraceOnly::Connection;
-$Net::Stomp::MooseHelpers::TraceOnly::Connection::VERSION = '2.8';
+$Net::Stomp::MooseHelpers::TraceOnly::Connection::VERSION = '2.9';
 {
   $Net::Stomp::MooseHelpers::TraceOnly::Connection::DIST = 'Net-Stomp-MooseHelpers';
 }{
@@ -53,6 +53,7 @@ sub subscribe { return 1 }
 sub unsubscribe { return 1 }
 sub ack { return 1 }
 sub current_host { return 0 }
+sub receipt_timeout { return undef }
 
 has _last_frame => (
     is => 'rw',
@@ -61,7 +62,7 @@ has _last_frame => (
 sub receive_frame {
     my ($self) = @_;
 
-    # hack to make send_transactional happy
+    # hack to make send_with_receipt happy
     if ($self->_last_frame && $self->_last_frame->headers->{'receipt'}) {
         return Net::Stomp::Frame->new({
             command => 'RECEIPT',
@@ -118,7 +119,7 @@ Net::Stomp::MooseHelpers::TraceOnly - role to replace the Net::Stomp connection
 
 =head1 VERSION
 
-version 2.8
+version 2.9
 
 =head1 SYNOPSIS
 
